@@ -1,6 +1,6 @@
 package Net::OAuth::Easy;
 BEGIN {
-  $Net::OAuth::Easy::VERSION = '0.001_03';
+  $Net::OAuth::Easy::VERSION = '0.001_04';
 }
 use Moose;
 use Digest::MD5 qw{md5_hex};
@@ -197,17 +197,26 @@ sub make_request {
    $self->clear_response if $self->has_response;
    my $request = ( ref($_[0]) && $_[0]->isa('Net::OAuth::Message') ) ? $_[0] : $self->build_request(grep { defined }@_);
 
+   #my $req = HTTP::Request->new( $request->request_method => ($request->request_method eq 'GET') ? $request->to_url : $request->request_url );
    my $req = HTTP::Request->new( $request->request_method => $request->to_url );
    $req->content($content) if defined $content;
    return $self->add_auth_headers($req, $request);
 }
 
+has [qw{oauth_header_realm oauth_header_separator}] => (
+   is => 'rw',
+   isa => 'Maybe[Str]',
+);
+
 sub add_auth_headers {
    my ($self, $http_req, $oauth_req) = @_;
    $self->exception_handle( 'HTTP::Request expected as first paramater') unless $http_req->isa('HTTP::Request');
    $self->exception_handle( 'Net::OAuth::Message expected as second paramater') unless $oauth_req->isa('Net::OAuth::Message');
-   $http_req->authorization( $oauth_req->to_authorization_header )
-      if $self->request_method eq 'POST';
+   $http_req->authorization( $oauth_req->to_authorization_header( 
+                                (defined $self->oauth_header_realm) ? $self->oauth_header_realm : undef ,
+                                (defined $self->oauth_header_separator) ? $self->oauth_header_separator : undef ,
+                             )
+                           ) if $http_req->method eq 'POST';
    return $http_req;
 }
 
